#!/usr/bin/python
# encoding: utf-8
import requests
import json
import base64
import hashlib


class Idphoto:
    def __init__(self, appcode, timeout=7):
        self.appcode = appcode
        self.timeout = timeout

        self.change_of_bg_url = 'https://idphotobg.market.alicloudapi.com/changebg'

        self.headers = {
            'Authorization': 'APPCODE ' + appcode,
        }

    def get_md5_data(self, body):
        """
        md5加密
        :param body_json:
        :return:
        """

        md5lib = hashlib.md5()
        md5lib.update(body.encode("utf-8"))
        body_md5 = md5lib.digest()
        body_md5 = base64.b64encode(body_md5)
        return body_md5

    def get_photo_base64(self, file_path):
        with open(file_path, 'rb') as fp:
            photo_base64 = base64.b64encode(fp.read())

        photo_base64 = photo_base64.decode('utf8')
        return photo_base64

    def aiseg_request(self, url, data, headers):
        resp = requests.post(url=url, data=data, headers=headers, timeout=self.timeout)
        res = {"status_code": resp.status_code}
        try:
            res["data"] = json.loads(resp.text)
            return res
        except Exception as e:
            print(e)

    def change_of_bg(self, photo_key, bk):
        """
        证据照更换背景
        :param photo_key:
        :param bk:
        :return:
        """
        body_json = {"photo_key": photo_key, "bk": bk}

        body = json.dumps(body_json)
        body_md5 = self.get_md5_data(body=body)
        self.headers.update({'Content-MD5': body_md5})

        data = self.aiseg_request(url=self.change_of_bg_url, data=body, headers=self.headers)
        return data


if __name__ == "__main__":
    file_path = "1.jpg"

    idphoto = Idphoto(appcode="你的appcode")
    photo_key = "9d0cab0b6058473e8405a8e9ced03c58"  # 此接口，需要在“证件照制作”接口中，加入请求参数"with_photo_key"，并将值设置为1, photo_key有效期为2小时
    d = idphoto.change_of_bg(photo_key=photo_key, bk="blue")
    print(d)
